==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/viking1/dialogs_it.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Questa dev'essere una nave vichinga!")

dialogId("dr-v-jiste", "font_big", "Sure, it`s a drakkar.")
dialogStr("Certo, è una drakar.")

dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Dev'essere affondata in fretta. I rematori sono ancora ai loro posti.")

dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Forse sono affondati di proposito. I guerrieri accompagnavano sempre i loro capi nella via per il Walhalla.")

dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Spaventoso. Sembra che siano ancora vivi.")

dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("La musica si è fermata!")

dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Hanno smesso di suonare!")

dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("La musica si è fermata di nuovo!")

dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("Oh, no!")

dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Ancora?")

dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Oh, non di nuovo!")

dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Cos'è successo?")

dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Di nuovo?")

dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("Oh, no!")

dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Quella musica si è fermata!")

dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Cosa stanno combinando?")

dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Come può essere?")

dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Calma, uomini. Assolo per Olaf!")

dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Non curatevene, uomini. Possiamo cantare da noi!")

dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Nessun problema, uomini. Possiamo cantare da noi, come ai vecchi tempi!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking1/dialogs_it.lua <==

dialogId("dr-m-tojesnad", "font_small", "This must be a Viking ship!")
dialogStr("Questa dev'essere una nave vichinga!")

dialogId("dr-v-jiste", "font_big", "Sure, it’s a drakkar.")
dialogStr("Certo, è una drakar.")

dialogId("dr-m-musela", "font_small", "She must have sunk fast. The oarsmen are still in their places.")
dialogStr("Dev'essere affondata in fretta. I rematori sono ancora ai loro posti.")

dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors would always accompany their leader on his way to Valhalla.")
dialogStr("Forse sono affondati di proposito. I guerrieri accompagnavano sempre i loro capi nella via per il Walhalla.")

dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
dialogStr("Spaventoso. Sembra che siano ancora vivi.")

dialogId("d1-1-hudba0", "font_viking1", "The music is gone!")
dialogStr("La musica si è fermata!")

dialogId("d1-1-hudba1", "font_viking1", "They stopped playing!")
dialogStr("Hanno smesso di suonare!")

dialogId("d1-1-hudba2", "font_viking1", "The music stopped again!")
dialogStr("La musica si è fermata di nuovo!")

dialogId("d1-2-brb0", "font_viking2", "Oh, no!")
dialogStr("Oh, no!")

dialogId("d1-2-brb1", "font_viking2", "Again?")
dialogStr("Ancora?")

dialogId("d1-2-brb2", "font_viking2", "Oh, not again!")
dialogStr("Oh, non di nuovo!")

dialogId("d1-3-brb0", "font_viking3", "What happened?")
dialogStr("Cos'è successo?")

dialogId("d1-3-brb1", "font_viking3", "Again?")
dialogStr("Di nuovo?")

dialogId("d1-3-brb2", "font_viking3", "Oh, no!")
dialogStr("Oh, no!")

dialogId("d1-4-brb0", "font_viking4", "The bloody music stopped!")
dialogStr("Quella musica si è fermata!")

dialogId("d1-4-brb1", "font_viking4", "What are they doing up there?")
dialogStr("Cosa stanno combinando?")

dialogId("d1-4-brb2", "font_viking4", "How could it be?")
dialogStr("Come può essere?")

dialogId("d1-5-nevadi0", "font_viking5", "Take it easy, boys. Solo for Olaf!")
dialogStr("Calma, uomini. Assolo per Olaf!")

dialogId("d1-5-nevadi1", "font_viking5", "Never mind that, boys. We can sing ourself!")
dialogStr("Non curatevene, uomini. Possiamo cantare da noi!")

dialogId("d1-5-nevadi2", "font_viking5", "Never mind, boys. We can sing ourself, like in the old times!")
dialogStr("Nessun problema, uomini. Possiamo cantare da noi, come ai vecchi tempi!")
